@@ -148,14 +148,14 @@ class main:
         proj = main.openproj()
         run = proj["run"]
         if run == "Installfile":
-          build.default({"x":"t","file":"Installfile","args":args})
+          default({"x":"t","file":"Installfile","args":args})
         else:
           os.system(run)
       if arg == "dependencies" or arg == "deps":
         proj = main.openproj()
         run = proj["dependencies"]
         if deps[0] == "Buildfile":
-          build.default({"x":"t","args":args})
+          default({"x":"t","args":args})
         else:
           for item in deps:
             os.system(item)
